@@ -152,6 +152,7 @@ class EWAHBaseOperator(BaseOperator):
         cleaner_class=EWAHCleaner,
         cleaner_callables=None,  # callables or list of callables to run during cleaning
         uploader_class=None,  # Future: deprecate dwh_engine and use this kwarg instead
+        deduplication_before_upload=False,
         *args,
         **kwargs
     ):
@@ -288,6 +289,7 @@ class EWAHBaseOperator(BaseOperator):
         self.default_values = default_values
         self.cleaner_class = cleaner_class
         self.cleaner_callables = cleaner_callables
+        self.deduplication_before_upload = deduplication_before_upload
 
         self.uploader_class = uploader_class or get_uploader(self.dwh_engine)
 
@@ -335,11 +337,13 @@ class EWAHBaseOperator(BaseOperator):
             # resolve conn id here & delete the object to avoid usage elsewhere
             self.source_conn = EWAHBaseHook.get_connection(self.source_conn_id)
             self.source_hook = self.source_conn.get_hook()
-            hook_callables = self.source_hook.get_cleaner_callables()
-            if callable(hook_callables):
-                cleaner_callables.append(hook_callables)
-            elif hook_callables:
-                cleaner_callables += hook_callables
+            if callable(getattr(self.source_hook, "get_cleaner_callables", None)):
+                hook_callables = self.source_hook.get_cleaner_callables()
+                if callable(hook_callables):
+                    cleaner_callables.append(hook_callables)
+                elif hook_callables:
+                    # Ought to be list of callables
+                    cleaner_callables += hook_callables
         del self.source_conn_id
 
         if self._CONN_TYPE:
@@ -372,6 +376,7 @@ class EWAHBaseOperator(BaseOperator):
             use_temp_pickling=self.use_temp_pickling,
             pickling_upload_chunk_size=self.pickling_upload_chunk_size,
             pickle_compression=self.pickle_compression,
+            deduplication_before_upload=self.deduplication_before_upload,
         )
 
         # If applicable: set the session's default time zone
